@@ -22,13 +22,13 @@ class LogicQuBit(Qubits, Gates, Circuit):
     def __init__(self, qubits_number = 3, **kwargs):
         self.__cuda = kwargs.get('cuda', True)
         self.__symbolic = kwargs.get('symbolic', False)
-        self.__first_left = kwargs.get('first_left', False)
+        self.__product_first_left = kwargs.get('product_first_left', False)
         self.__qubits_number = qubits_number
         if(self.__symbolic):
             self.__cuda = False
         super().setCuda(self.__cuda)
-        super().__init__(qubits_number, self.__symbolic, self.__first_left)
-        Gates.__init__(self, qubits_number, self.__first_left)
+        super().__init__(qubits_number, self.__symbolic, self.__product_first_left)
+        Gates.__init__(self, qubits_number, self.__product_first_left)
         Circuit.__init__(self)
 
     def X(self, target):
@@ -194,7 +194,7 @@ class LogicQuBit(Qubits, Gates, Circuit):
             tlist = [self.ID() for tl in range(self.__qubits_number)]
             blist = [i >> bl & 0x1 for bl in range(size_p)]  # bit list, bits de cada i
             cnt = 0
-            if (self.__first_left):
+            if (self.__product_first_left):
                 sing = 1
                 offset_list = 0
                 offset_cnt = 0
@@ -221,9 +221,10 @@ class LogicQuBit(Qubits, Gates, Circuit):
         self.setMeasuredValues(result)
         return result
 
-    def Measure(self, target):  # ex: medir de 5qubits: 2,1,4 do valor "010" -> M010 = |1><1| x |0><0| x 1 x |0><0| x 1
+    def Measure(self, target, fisrt_left = False):  # ex: medir de 5qubits: 2,1,4 do valor "010" -> M010 = |1><1| x |0><0| x 1 x |0><0| x 1
         target = self.qubitsToList(target)
-        #target.reverse()
+        if(fisrt_left):
+            target.reverse()
         self.setMeasuredQubits(target)
         self.addOp("Measure", target)
         density_m = self.DensityMatrix()
@@ -238,7 +239,7 @@ class LogicQuBit(Qubits, Gates, Circuit):
                     tlist[value-1] = super().P0()
                 else:
                     tlist[value-1] = super().P1()
-            if (not self.__first_left):
+            if (not self.__product_first_left):
                 tlist.reverse()
             M = self.kronProduct(tlist)
             measure = (density_m * M).trace()  # valor esperado
